Learn R Programming

MSUthemes (version 1.0.0)

bigten_colors_primary: Named vector of Big Ten primary colors for reliable institution matching

Description

Named vector of Big Ten primary colors for reliable institution matching

Usage

bigten_colors_primary

Arguments

Format

An object of class character of length 21.