Learn R Programming

MSUthemes (version 1.0.0)

bigten_colors_secondary: Named vector of Big Ten secondary colors for reliable institution matching

Description

Named vector of Big Ten secondary colors for reliable institution matching

Usage

bigten_colors_secondary

Arguments

Format

An object of class character of length 21.